# -*- coding: utf-8 -*-
"""
    aip public
"""

from .ocr import AipOcr
from .nlp import AipNlp
from .face import AipFace
from .imagecensor import AipImageCensor
from .imagecensor import AipImageCensor as AipContentCensor
from .kg import AipKg
from .speech import AipSpeech
from .imageclassify import AipImageClassify
from .imagesearch import AipImageSearch
from .bodyanalysis import AipBodyAnalysis
from .easydl import EasyDL